
rstudio_setup <- function(path, ...) {
    # create project
    setup_project(path = path)
    invisible(NULL)
}
